@@ -1,22 +1,9 @@
-/* This file is part of the KDE libraries
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Reginald Stadlbauer <reggie@kde.org>
+    SPDX-FileCopyrightText: 2017 Harald Sitter <sitter@kde.org>
 
-   Copyright (C) 1999 Reginald Stadlbauer <reggie@kde.org>
-   Copyright (C) 2017 Harald Sitter <sitter@kde.org>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kcharselect.h"
@@ -34,6 +21,7 @@
 #include <QFontComboBox>
 #include <QHeaderView>
 #include <QLineEdit>
+#include <QRegularExpression>
 #include <QSplitter>
 #include <QToolButton>
 #include <QTextBrowser>
@@ -294,6 +282,7 @@ void KCharSelectTablePrivate::_k_resizeCells()
     const int rows = model->rowCount();
     q->setUpdatesEnabled(false);
     QHeaderView *hHeader = q->horizontalHeader();
+    hHeader->setMinimumSectionSize(new_w);
     const int spaceLeft = viewportWidth - new_w * columns;
     for (int i = 0; i <= columns; ++i) {
         if (i < spaceLeft) {
@@ -313,6 +302,7 @@ void KCharSelectTablePrivate::_k_resizeCells()
     if (new_h < 5 || new_h < 4 + fontHeight) {
         new_h = qMax(5, 4 + fontHeight);
     }
+    vHeader->setMinimumSectionSize(new_h);
     for (int i = 0; i < rows; ++i) {
         vHeader->resizeSection(i, new_h);
     }
@@ -358,13 +348,11 @@ void KCharSelectTable::keyPressEvent(QKeyEvent *e)
 /* Class: KCharSelect                                             */
 /******************************************************************/
 
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
 KCharSelect::KCharSelect(QWidget *parent, const Controls controls)
     : QWidget(parent), d(new KCharSelectPrivate(this))
 {
     initWidget(controls, nullptr);
 }
-#endif
 
 KCharSelect::KCharSelect(
     QWidget *parent
@@ -384,8 +372,8 @@ void attachToActionParent(QAction *action, QObject *actionParent, const QList<QK
     action->setParent(actionParent);
 
     if (actionParent->inherits("KActionCollection")) {
-        QMetaObject::invokeMethod(actionParent, "addAction", Q_ARG(QString, action->objectName()), Q_ARG(QAction *, action));
-        QMetaObject::invokeMethod(actionParent, "setDefaultShortcuts", Q_ARG(QAction *, action), Q_ARG(QList<QKeySequence>, shortcuts));
+        QMetaObject::invokeMethod(actionParent, "addAction", Q_ARG(QString, action->objectName()), Q_ARG(QAction*, action));
+        QMetaObject::invokeMethod(actionParent, "setDefaultShortcuts", Q_ARG(QAction*, action), Q_ARG(QList<QKeySequence>, shortcuts));
     } else {
         action->setShortcuts(shortcuts);
     }
@@ -396,20 +384,20 @@ void KCharSelect::initWidget(const Controls controls, QObject *actionParent)
     d->actionParent = actionParent;
 
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    mainLayout->setMargin(0);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
     if (SearchLine & controls) {
         QHBoxLayout *searchLayout = new QHBoxLayout();
         mainLayout->addLayout(searchLayout);
         d->searchLine = new QLineEdit(this);
         searchLayout->addWidget(d->searchLine);
-        d->searchLine->setPlaceholderText(tr("Enter a search term or character here"));
+        d->searchLine->setPlaceholderText(tr("Enter a search term or character...", "@info:placeholder"));
         d->searchLine->setClearButtonEnabled(true);
-        d->searchLine->setToolTip(tr("Enter a search term or character here"));
+        d->searchLine->setToolTip(tr("Enter a search term or character here", "@info:tooltip"));
 
         QAction *findAction = new QAction(this);
         connect(findAction, &QAction::triggered, this, [this]() { d->_k_activateSearchLine(); });
         findAction->setObjectName(QStringLiteral("edit_find"));
-        findAction->setText(tr("&Find..."));
+        findAction->setText(tr("&Find...", "@action"));
         findAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-find")));
         attachToActionParent(findAction, actionParent, QKeySequence::keyBindings(QKeySequence::Find));
 
@@ -429,28 +417,28 @@ void KCharSelect::initWidget(const Controls controls, QObject *actionParent)
     d->backButton = new QToolButton(this);
     comboLayout->addWidget(d->backButton);
     d->backButton->setEnabled(false);
-    d->backButton->setText(tr("Previous in History", "Goes to previous character"));
+    d->backButton->setText(tr("Previous in History", "@action:button Goes to previous character"));
     d->backButton->setIcon(QIcon::fromTheme(QStringLiteral("go-previous")));
-    d->backButton->setToolTip(tr("Previous Character in History"));
+    d->backButton->setToolTip(tr("Go to previous character in history", "@info:tooltip"));
 
     d->forwardButton = new QToolButton(this);
     comboLayout->addWidget(d->forwardButton);
     d->forwardButton->setEnabled(false);
-    d->forwardButton->setText(tr("Next in History", "Goes to next character"));
+    d->forwardButton->setText(tr("Next in History", "@action:button Goes to next character"));
     d->forwardButton->setIcon(QIcon::fromTheme(QStringLiteral("go-next")));
-    d->forwardButton->setToolTip(tr("Next Character in History"));
+    d->forwardButton->setToolTip(tr("Go to next character in history", "info:tooltip"));
 
     QAction *backAction = new QAction(this);
     connect(backAction, &QAction::triggered, d->backButton, &QAbstractButton::animateClick);
     backAction->setObjectName(QStringLiteral("go_back"));
-    backAction->setText(tr("&Back", "go back"));
+    backAction->setText(tr("&Back", "@action go back"));
     backAction->setIcon(QIcon::fromTheme(QStringLiteral("go-previous")));
     attachToActionParent(backAction, actionParent, QKeySequence::keyBindings(QKeySequence::Back));
 
     QAction *forwardAction = new QAction(this);
     connect(forwardAction, &QAction::triggered, d->forwardButton, &QAbstractButton::animateClick);
     forwardAction->setObjectName(QStringLiteral("go_forward"));
-    forwardAction->setText(tr("&Forward", "go forward"));
+    forwardAction->setText(tr("&Forward", "@action go forward"));
     forwardAction->setIcon(QIcon::fromTheme(QStringLiteral("go-next")));
     attachToActionParent(forwardAction, actionParent, QKeySequence::keyBindings(QKeySequence::Forward));
 
@@ -464,10 +452,12 @@ void KCharSelect::initWidget(const Controls controls, QObject *actionParent)
     connect(d->forwardButton, &QToolButton::clicked, this, [this]() { d->_k_forward(); });
 
     d->sectionCombo = new QComboBox(this);
-    d->sectionCombo->setToolTip(tr("Select a category"));
+    d->sectionCombo->setObjectName(QStringLiteral("sectionCombo"));
+    d->sectionCombo->setToolTip(tr("Select a category", "@info:tooltip"));
     comboLayout->addWidget(d->sectionCombo);
     d->blockCombo = new QComboBox(this);
-    d->blockCombo->setToolTip(tr("Select a block to be displayed"));
+    d->blockCombo->setObjectName(QStringLiteral("blockCombo"));
+    d->blockCombo->setToolTip(tr("Select a block to be displayed", "@info:tooltip"));
     d->blockCombo->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
     comboLayout->addWidget(d->blockCombo, 1);
     d->sectionCombo->addItems(s_data()->sectionList());
@@ -480,14 +470,14 @@ void KCharSelect::initWidget(const Controls controls, QObject *actionParent)
     comboLayout->addWidget(d->fontCombo);
     d->fontCombo->setEditable(true);
     d->fontCombo->resize(d->fontCombo->sizeHint());
-    d->fontCombo->setToolTip(tr("Set font"));
+    d->fontCombo->setToolTip(tr("Set font", "@info:tooltip"));
 
     d->fontSizeSpinBox = new QSpinBox(this);
     comboLayout->addWidget(d->fontSizeSpinBox);
     d->fontSizeSpinBox->setValue(QWidget::font().pointSize());
     d->fontSizeSpinBox->setRange(1, 400);
     d->fontSizeSpinBox->setSingleStep(1);
-    d->fontSizeSpinBox->setToolTip(tr("Set font size"));
+    d->fontSizeSpinBox->setToolTip(tr("Set font size", "@info:tooltip"));
 
     connect(d->fontCombo, SIGNAL(currentIndexChanged(QString)), this, SLOT(_k_fontSelected()));
     connect(d->fontSizeSpinBox, SIGNAL(valueChanged(int)), this, SLOT(_k_fontSelected()));
@@ -519,7 +509,6 @@ void KCharSelect::initWidget(const Controls controls, QObject *actionParent)
     d->charTable = new KCharSelectTable(this, QFont());
     if (CharacterTable & controls) {
         splitter->addWidget(d->charTable);
-        d->charTable->setFocus(Qt::OtherFocusReason);
     } else {
         d->charTable->hide();
     }
@@ -546,9 +535,13 @@ void KCharSelect::initWidget(const Controls controls, QObject *actionParent)
     connect(d->detailBrowser, SIGNAL(anchorClicked(QUrl)), this, SLOT(_k_linkClicked(QUrl)));
 
     setFocusPolicy(Qt::StrongFocus);
-    setFocusProxy(d->charTable);
-    d->_k_sectionSelected(0);
-    d->_k_blockSelected(0);
+    if(SearchLine & controls) {
+        setFocusProxy(d->searchLine);
+    } else {
+        setFocusProxy(d->charTable);
+    }
+
+    d->_k_sectionSelected(0); // this will also call _k_blockSelected(0)
     setCurrentCodePoint(QChar::Null);
 
     d->historyEnabled = true;
@@ -605,7 +598,9 @@ QList<QChar> KCharSelect::displayedChars() const
         qFatal("You must use KCharSelect::displayedCodePoints instead of KCharSelect::displayedChars");
     }
     QList<QChar> result;
-    foreach (uint c, d->charTable->displayedChars()) {
+    const auto displayedChars = d->charTable->displayedChars();
+    result.reserve(displayedChars.size());
+    for (uint c : displayedChars) {
         result.append(QChar(c));
     }
     return result;
@@ -774,85 +769,85 @@ void KCharSelect::KCharSelectPrivate::_k_updateCurrentChar(uint c)
 
 void KCharSelect::KCharSelectPrivate::_k_slotUpdateUnicode(uint c)
 {
-    QString html = QStringLiteral("<p>") + tr("Character:") + QLatin1Char(' ') + s_data()->display(c, charTable->font()) + QLatin1Char(' ') +
-                   s_data()->formatCode(c)  + QStringLiteral("<br />");
+    QString html = QLatin1String("<p>") + tr("Character:") + QLatin1Char(' ') + s_data()->display(c, charTable->font()) + QLatin1Char(' ') +
+                   s_data()->formatCode(c)  + QLatin1String("<br />");
 
     QString name = s_data()->name(c);
     if (!name.isEmpty()) {
         //is name ever empty? </p> should always be there...
-        html += tr("Name: ") + name.toHtmlEscaped() + QStringLiteral("</p>");
+        html += tr("Name: ") + name.toHtmlEscaped() + QLatin1String("</p>");
     }
-    QStringList aliases = s_data()->aliases(c);
-    QStringList notes = s_data()->notes(c);
-    QVector<uint> seeAlso = s_data()->seeAlso(c);
-    QStringList equivalents = s_data()->equivalents(c);
-    QStringList approxEquivalents = s_data()->approximateEquivalents(c);
-    QVector<uint> decomposition = s_data()->decomposition(c);
+    const QStringList aliases = s_data()->aliases(c);
+    const QStringList notes = s_data()->notes(c);
+    const QVector<uint> seeAlso = s_data()->seeAlso(c);
+    const QStringList equivalents = s_data()->equivalents(c);
+    const QStringList approxEquivalents = s_data()->approximateEquivalents(c);
+    const QVector<uint> decomposition = s_data()->decomposition(c);
     if (!(aliases.isEmpty() && notes.isEmpty() && seeAlso.isEmpty() && equivalents.isEmpty() && approxEquivalents.isEmpty() && decomposition.isEmpty())) {
-        html += QStringLiteral("<p><b>") + tr("Annotations and Cross References") + QStringLiteral("</b></p>");
+        html += QLatin1String("<p><b>") + tr("Annotations and Cross References") + QLatin1String("</b></p>");
     }
 
     if (!aliases.isEmpty()) {
-        html += QStringLiteral("<p style=\"margin-bottom: 0px;\">") + tr("Alias names:") + QStringLiteral("</p><ul style=\"margin-top: 0px;\">");
-        foreach (const QString &alias, aliases) {
-            html += QStringLiteral("<li>") + alias.toHtmlEscaped() + QStringLiteral("</li>");
+        html += QLatin1String("<p style=\"margin-bottom: 0px;\">") + tr("Alias names:") + QLatin1String("</p><ul style=\"margin-top: 0px;\">");
+        for (const QString &alias : aliases) {
+            html += QLatin1String("<li>") + alias.toHtmlEscaped() + QLatin1String("</li>");
         }
-        html += QStringLiteral("</ul>");
+        html += QLatin1String("</ul>");
     }
 
     if (!notes.isEmpty()) {
-        html += QStringLiteral("<p style=\"margin-bottom: 0px;\">") + tr("Notes:") + QStringLiteral("</p><ul style=\"margin-top: 0px;\">");
-        foreach (const QString &note, notes) {
-            html += QStringLiteral("<li>") + createLinks(note.toHtmlEscaped()) + QStringLiteral("</li>");
+        html += QLatin1String("<p style=\"margin-bottom: 0px;\">") + tr("Notes:") + QLatin1String("</p><ul style=\"margin-top: 0px;\">");
+        for (const QString &note : notes) {
+            html += QLatin1String("<li>") + createLinks(note.toHtmlEscaped()) + QLatin1String("</li>");
         }
-        html += QStringLiteral("</ul>");
+        html += QLatin1String("</ul>");
     }
 
     if (!seeAlso.isEmpty()) {
-        html += QStringLiteral("<p style=\"margin-bottom: 0px;\">") + tr("See also:") + QStringLiteral("</p><ul style=\"margin-top: 0px;\">");
-        foreach (uint c2, seeAlso) {
+        html += QLatin1String("<p style=\"margin-bottom: 0px;\">") + tr("See also:") + QLatin1String("</p><ul style=\"margin-top: 0px;\">");
+        for (uint c2 : seeAlso) {
             if (!allPlanesEnabled && QChar::requiresSurrogates(c2)) {
                 continue;
             }
-            html += QStringLiteral("<li><a href=\"") + QString::number(c2, 16) + QStringLiteral("\">");
+            html += QLatin1String("<li><a href=\"") + QString::number(c2, 16) + QLatin1String("\">");
             if (s_data()->isPrint(c2)) {
-                html += QStringLiteral("&#8206;&#") + QString::number(c2) + QStringLiteral("; ");
+                html += QLatin1String("&#8206;&#") + QString::number(c2) + QLatin1String("; ");
             }
-            html += s_data()->formatCode(c2) + QLatin1Char(' ') + s_data()->name(c2).toHtmlEscaped() + QStringLiteral("</a></li>");
+            html += s_data()->formatCode(c2) + QLatin1Char(' ') + s_data()->name(c2).toHtmlEscaped() + QLatin1String("</a></li>");
         }
-        html += QStringLiteral("</ul>");
+        html += QLatin1String("</ul>");
     }
 
     if (!equivalents.isEmpty()) {
-        html += QStringLiteral("<p style=\"margin-bottom: 0px;\">") + tr("Equivalents:") + QStringLiteral("</p><ul style=\"margin-top: 0px;\">");
-        foreach (const QString &equivalent, equivalents) {
-            html += QStringLiteral("<li>") + createLinks(equivalent.toHtmlEscaped()) + QStringLiteral("</li>");
+        html += QLatin1String("<p style=\"margin-bottom: 0px;\">") + tr("Equivalents:") + QLatin1String("</p><ul style=\"margin-top: 0px;\">");
+        for (const QString &equivalent : equivalents) {
+            html += QLatin1String("<li>") + createLinks(equivalent.toHtmlEscaped()) + QLatin1String("</li>");
         }
-        html += QStringLiteral("</ul>");
+        html += QLatin1String("</ul>");
     }
 
     if (!approxEquivalents.isEmpty()) {
-        html += QStringLiteral("<p style=\"margin-bottom: 0px;\">") + tr("Approximate equivalents:") + QStringLiteral("</p><ul style=\"margin-top: 0px;\">");
-        foreach (const QString &approxEquivalent, approxEquivalents) {
-            html += QStringLiteral("<li>") + createLinks(approxEquivalent.toHtmlEscaped()) + QStringLiteral("</li>");
+        html += QLatin1String("<p style=\"margin-bottom: 0px;\">") + tr("Approximate equivalents:") + QLatin1String("</p><ul style=\"margin-top: 0px;\">");
+        for (const QString &approxEquivalent : approxEquivalents) {
+            html += QLatin1String("<li>") + createLinks(approxEquivalent.toHtmlEscaped()) + QLatin1String("</li>");
         }
-        html += QStringLiteral("</ul>");
+        html += QLatin1String("</ul>");
     }
 
     if (!decomposition.isEmpty()) {
-        html += QStringLiteral("<p style=\"margin-bottom: 0px;\">") +  tr("Decomposition:") + QStringLiteral("</p><ul style=\"margin-top: 0px;\">");
-        foreach (uint c2, decomposition) {
+        html += QLatin1String("<p style=\"margin-bottom: 0px;\">") +  tr("Decomposition:") + QLatin1String("</p><ul style=\"margin-top: 0px;\">");
+        for (uint c2 : decomposition) {
             if (!allPlanesEnabled && QChar::requiresSurrogates(c2)) {
                 continue;
             }
-            html += QStringLiteral("<li>") + createLinks(s_data()->formatCode(c2, 4, QStringLiteral(""))) + QStringLiteral("</li>");
+            html += QLatin1String("<li>") + createLinks(s_data()->formatCode(c2, 4, QString())) + QLatin1String("</li>");
         }
-        html += QStringLiteral("</ul>");
+        html += QLatin1String("</ul>");
     }
 
     QStringList unihan = s_data()->unihanInfo(c);
     if (unihan.count() == 7) {
-        html += QStringLiteral("<p><b>") + tr("CJK Ideograph Information") + QStringLiteral("</b></p><p>");
+        html += QLatin1String("<p><b>") + tr("CJK Ideograph Information") + QLatin1String("</b></p><p>");
         bool newline = true;
         if (!unihan[0].isEmpty()) {
             html += tr("Definition in English: ") + unihan[0];
@@ -860,100 +855,98 @@ void KCharSelect::KCharSelectPrivate::_k_slotUpdateUnicode(uint c)
         }
         if (!unihan[2].isEmpty()) {
             if (!newline) {
-                html += QStringLiteral("<br>");
+                html += QLatin1String("<br>");
             }
             html += tr("Mandarin Pronunciation: ") + unihan[2];
             newline = false;
         }
         if (!unihan[1].isEmpty()) {
             if (!newline) {
-                html += QStringLiteral("<br>");
+                html += QLatin1String("<br>");
             }
             html += tr("Cantonese Pronunciation: ") + unihan[1];
             newline = false;
         }
         if (!unihan[6].isEmpty()) {
             if (!newline) {
-                html += QStringLiteral("<br>");
+                html += QLatin1String("<br>");
             }
             html += tr("Japanese On Pronunciation: ") + unihan[6];
             newline = false;
         }
         if (!unihan[5].isEmpty()) {
             if (!newline) {
-                html += QStringLiteral("<br>");
+                html += QLatin1String("<br>");
             }
             html += tr("Japanese Kun Pronunciation: ") + unihan[5];
             newline = false;
         }
         if (!unihan[3].isEmpty()) {
             if (!newline) {
-                html += QStringLiteral("<br>");
+                html += QLatin1String("<br>");
             }
             html += tr("Tang Pronunciation: ") + unihan[3];
             newline = false;
         }
         if (!unihan[4].isEmpty()) {
             if (!newline) {
-                html += QStringLiteral("<br>");
+                html += QLatin1String("<br>");
             }
             html += tr("Korean Pronunciation: ") + unihan[4];
             newline = false;
         }
-        html += QStringLiteral("</p>");
+        html += QLatin1String("</p>");
     }
 
-    html += QStringLiteral("<p><b>") + tr("General Character Properties") + QStringLiteral("</b><br>");
-    html += tr("Block: ") + s_data()->block(c) + QStringLiteral("<br>");
-    html += tr("Unicode category: ") + s_data()->categoryText(s_data()->category(c)) + QStringLiteral("</p>");
+    html += QLatin1String("<p><b>") + tr("General Character Properties") + QLatin1String("</b><br>");
+    html += tr("Block: ") + s_data()->block(c) + QLatin1String("<br>");
+    html += tr("Unicode category: ") + s_data()->categoryText(s_data()->category(c)) + QLatin1String("</p>");
 
-    QByteArray utf8 = QString::fromUcs4(&c, 1).toUtf8();
+    const QByteArray utf8 = QString::fromUcs4(&c, 1).toUtf8();
 
-    html += QStringLiteral("<p><b>") + tr("Various Useful Representations") + QStringLiteral("</b><br>");
+    html += QLatin1String("<p><b>") + tr("Various Useful Representations") + QLatin1String("</b><br>");
     html += tr("UTF-8:");
-    foreach (unsigned char c, utf8) {
+    for (unsigned char c : utf8) {
         html += QLatin1Char(' ') + s_data()->formatCode(c, 2, QStringLiteral("0x"));
     }
-    html += QStringLiteral("<br>") + tr("UTF-16: ");
+    html += QLatin1String("<br>") + tr("UTF-16: ");
     if (QChar::requiresSurrogates(c)) {
         html += s_data()->formatCode(QChar::highSurrogate(c), 4, QStringLiteral("0x"));
         html += QLatin1Char(' ') + s_data->formatCode(QChar::lowSurrogate(c), 4, QStringLiteral("0x"));
     } else {
         html += s_data()->formatCode(c, 4, QStringLiteral("0x"));
     }
-    html += QStringLiteral("<br>") + tr("C octal escaped UTF-8: ");
-    foreach (unsigned char c, utf8) {
+    html += QLatin1String("<br>") + tr("C octal escaped UTF-8: ");
+    for (unsigned char c : utf8) {
         html += s_data()->formatCode(c, 3, QStringLiteral("\\"), 8);
     }
-    html += QStringLiteral("<br>") + tr("XML decimal entity:") + QStringLiteral(" &amp;#") + QString::number(c) + QStringLiteral(";</p>");
+    html += QLatin1String("<br>") + tr("XML decimal entity:") + QLatin1String(" &amp;#") + QString::number(c) + QLatin1String(";</p>");
 
     detailBrowser->setHtml(html);
 }
 
 QString KCharSelect::KCharSelectPrivate::createLinks(QString s)
 {
-    QRegExp rx(QStringLiteral("\\b([\\dABCDEF]{4,5})\\b"));
-
-    QStringList chars;
-    int pos = 0;
-
-    while ((pos = rx.indexIn(s, pos)) != -1) {
-        chars << rx.cap(1);
-        pos += rx.matchedLength();
+    const QRegularExpression rx(QStringLiteral("\\b([\\dABCDEF]{4,5})\\b"));
+    QRegularExpressionMatchIterator iter = rx.globalMatch(s);
+    QRegularExpressionMatch match;
+    QSet<QString> chars;
+    while (iter.hasNext()) {
+        match = iter.next();
+        chars.insert(match.captured(1));
     }
 
-    QSet<QString> chars2 = QSet<QString>::fromList(chars);
-    foreach (const QString &c, chars2) {
+    for (const QString &c : qAsConst(chars)) {
         int unicode = c.toInt(nullptr, 16);
         if (!allPlanesEnabled && QChar::requiresSurrogates(unicode)) {
             continue;
         }
-        QString link = QStringLiteral("<a href=\"") + c + QStringLiteral("\">");
+        QString link = QLatin1String("<a href=\"") + c + QLatin1String("\">");
         if (s_data()->isPrint(unicode)) {
-            link += QStringLiteral("&#8206;&#") + QString::number(unicode) + QStringLiteral(";&nbsp;");
+            link += QLatin1String("&#8206;&#") + QString::number(unicode) + QLatin1String(";&nbsp;");
         }
-        link += QStringLiteral("U+") + c + QLatin1Char(' ');
-        link += s_data()->name(unicode).toHtmlEscaped() + QStringLiteral("</a>");
+        link += QLatin1String("U+") + c + QLatin1Char(' ');
+        link += s_data()->name(unicode).toHtmlEscaped() + QLatin1String("</a>");
         s.replace(c, link);
     }
     return s;
@@ -962,8 +955,8 @@ QString KCharSelect::KCharSelectPrivate::createLinks(QString s)
 void KCharSelect::KCharSelectPrivate::_k_sectionSelected(int index)
 {
     blockCombo->clear();
-    QVector<int> blocks = s_data()->sectionContents(index);
-    foreach (int block, blocks) {
+    const QVector<int> blocks = s_data()->sectionContents(index);
+    for (int block : blocks) {
         if (!allPlanesEnabled) {
             const QVector<uint> contents = s_data()->blockContents(block);
             if (!contents.isEmpty() && QChar::requiresSurrogates(contents.at(0))) {
@@ -1063,7 +1056,7 @@ QVariant KCharSelectItemModel::data(const QModelIndex &index, int role) const
     int pos = m_columns * (index.row()) + index.column();
     if (!index.isValid() || pos < 0 || pos >= m_chars.size()
             || index.row() < 0 || index.column() < 0) {
-        if (role == Qt::BackgroundColorRole) {
+        if (role == Qt::BackgroundRole) {
             return QVariant(qApp->palette().color(QPalette::Button));
         }
         return QVariant();
@@ -1071,8 +1064,8 @@ QVariant KCharSelectItemModel::data(const QModelIndex &index, int role) const
 
     uint c = m_chars[pos];
     if (role == Qt::ToolTipRole) {
-        QString result = s_data()->display(c, m_font) + QStringLiteral("<br />") + s_data()->name(c).toHtmlEscaped() + QStringLiteral("<br />") +
-                         tr("Unicode code point:") + QLatin1Char(' ') + s_data()->formatCode(c) + QStringLiteral("<br />") +
+        QString result = s_data()->display(c, m_font) + QLatin1String("<br />") + s_data()->name(c).toHtmlEscaped() + QLatin1String("<br />") +
+                         tr("Unicode code point:") + QLatin1Char(' ') + s_data()->formatCode(c) + QLatin1String("<br />") +
                          tr("In decimal", "Character") + QLatin1Char(' ') + QString::number(c);
         return QVariant(result);
     } else if (role == Qt::TextAlignmentRole) {
@@ -1082,7 +1075,7 @@ QVariant KCharSelectItemModel::data(const QModelIndex &index, int role) const
             return QVariant(QString::fromUcs4(&c, 1));
         }
         return QVariant();
-    } else if (role == Qt::BackgroundColorRole) {
+    } else if (role == Qt::BackgroundRole) {
         QFontMetrics fm = QFontMetrics(m_font);
         if (fm.inFontUcs4(c) && s_data()->isPrint(c)) {
             return QVariant(qApp->palette().color(QPalette::Base));
