@@ -1,22 +1,9 @@
 /*
-    Copyright (C) 1997 Bernd Johannes Wuebben <wuebben@kde.org>
-    Copyright (c) 1999 Preston Brown <pbrown@kde.org>
-    Copyright (c) 1999 Mario Weilguni <mweilguni@kde.org>
+    SPDX-FileCopyrightText: 1997 Bernd Johannes Wuebben <wuebben@kde.org>
+    SPDX-FileCopyrightText: 1999 Preston Brown <pbrown@kde.org>
+    SPDX-FileCopyrightText: 1999 Mario Weilguni <mweilguni@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef K_FONT_CHOOSER_H
 #define K_FONT_CHOOSER_H
@@ -64,25 +51,34 @@ public:
 
     /**
      * Flags for selecting which font attributes to change
+     * @see FontDiffFlags
      */
     enum FontDiff {
-        NoFontDiffFlags = 0,
+        NoFontDiffFlags = 0, ///< No flags set
         FontDiffFamily = 1,  ///< Identifies a requested change in the font family.
         FontDiffStyle = 2,   ///< Identifies a requested change in the font style.
         FontDiffSize = 4,    ///< Identifies a requested change in the font size.
         AllFontDiffs = FontDiffFamily | FontDiffStyle | FontDiffSize
     };
+    /**
+     * Stores an combination of #FontDiff values.
+     */
     Q_DECLARE_FLAGS(FontDiffFlags, FontDiff)
 
     /**
      * Flags for selecting what is displayed in the widget.
+     * @see DisplayFlags
      */
     enum DisplayFlag {
-        NoDisplayFlags = 0,
-        FixedFontsOnly = 1, ///< Only show fixed fonts, excluding proportional fonts
-        DisplayFrame = 2,   ///< Show a visual frame around the chooser
-        ShowDifferences = 4 ///< Display the font differences interfaces
+        NoDisplayFlags = 0,     ///< No flags set
+        FixedFontsOnly = 1,     ///< Only show monospaced/fixed-width fonts, excluding proportional fonts, (the
+                                ///< checkbox to toggle showing only monospaced fonts is not shown in this case)
+        DisplayFrame = 2,       ///< Show a visual frame around the chooser
+        ShowDifferences = 4,    ///< Display the font differences interfaces
     };
+    /**
+     * Stores a combination of #DisplayFlag values.
+     */
     Q_DECLARE_FLAGS(DisplayFlags, DisplayFlag)
 
     /**
@@ -123,7 +119,7 @@ public:
     /**
      * Destructs the font chooser.
      */
-    virtual ~KFontChooser();
+    ~KFontChooser() override;
 
     /**
      * Enables or disable a font column in the chooser.
@@ -253,7 +249,7 @@ public:
     /**
      * Reimplemented for internal reasons.
      */
-    QSize sizeHint(void) const Q_DECL_OVERRIDE;
+    QSize sizeHint(void) const override;
 
 Q_SIGNALS:
     /**
@@ -267,7 +263,6 @@ private:
 
     Q_DISABLE_COPY(KFontChooser)
 
-    Q_PRIVATE_SLOT(d, void _k_toggled_checkbox())
     Q_PRIVATE_SLOT(d, void _k_family_chosen_slot(const QString &))
     Q_PRIVATE_SLOT(d, void _k_size_chosen_slot(const QString &))
     Q_PRIVATE_SLOT(d, void _k_style_chosen_slot(const QString &))
