@@ -1,23 +1,11 @@
-/* This file is part of the KDE libraries
- *
- * Copyright (c) 2011 Aurélien Gâteau <agateau@kde.org>
- * Copyright (c) 2014 Dominik Haumann <dhaumann@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
- */
+/*
+    This file is part of the KDE libraries
+
+    SPDX-FileCopyrightText: 2011 Aurélien Gâteau <agateau@kde.org>
+    SPDX-FileCopyrightText: 2014 Dominik Haumann <dhaumann@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 #include "kmessagewidget.h"
 
 #include <QAction>
@@ -85,8 +73,8 @@ void KMessageWidgetPrivate::init(KMessageWidget *q_ptr)
     QObject::connect(textLabel, &QLabel::linkHovered, q, &KMessageWidget::linkHovered);
 
     QAction *closeAction = new QAction(q);
-    closeAction->setText(KMessageWidget::tr("&Close"));
-    closeAction->setToolTip(KMessageWidget::tr("Close message"));
+    closeAction->setText(KMessageWidget::tr("&Close", "@action:button"));
+    closeAction->setToolTip(KMessageWidget::tr("Close message", "@info:tooltip"));
     QStyleOptionFrame opt;
     opt.initFrom(q);
     closeAction->setIcon(q->style()->standardIcon(QStyle::SP_DialogCloseButton, &opt, q));
@@ -315,7 +303,7 @@ int KMessageWidget::heightForWidth(int width) const
     ensurePolished();
     return QFrame::heightForWidth(width);
 }
-#include <QDebug>
+
 void KMessageWidget::paintEvent(QPaintEvent *event)
 {
     Q_UNUSED(event)
