@@ -1,23 +1,12 @@
-// Copyright (C) 2000 Peter Putzer <putzer@kde.org>
+/*
+    SPDX-FileCopyrightText: 2000 Peter Putzer <putzer@kde.org>
 
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public
-// License as published by the Free Software Foundation; either
-// version 2.1 of the License, or (at your option) any later version.
-
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Lesser General Public License for more details.
-
-// You should have received a copy of the GNU Lesser General Public
-// License along with this library; if not, write to the Free Software
-// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-// 02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "kurllabel.h"
 
-#include <QtCore/QTimer>
+#include <QTimer>
 #include <QApplication>
 #include <QMouseEvent>
 #include <QPalette>
@@ -116,17 +105,23 @@ void KUrlLabel::mouseReleaseEvent(QMouseEvent *event)
     switch (event->button()) {
     case Qt::LeftButton:
         emit leftClickedUrl();
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 65)
         emit leftClickedUrl(d->url);
+#endif
         break;
 
     case Qt::MidButton:
         emit middleClickedUrl();
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 65)
         emit middleClickedUrl(d->url);
+#endif
         break;
 
     case Qt::RightButton:
         emit rightClickedUrl();
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 65)
         emit rightClickedUrl(d->url);
+#endif
         break;
 
     default:
@@ -275,10 +270,20 @@ void KUrlLabel::enterEvent(QEvent *event)
 {
     QLabel::enterEvent(event);
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    if (!d->alternatePixmap.isNull()) {
+        const auto currentPixmap = pixmap(Qt::ReturnByValue);
+        if (!currentPixmap.isNull()) {
+            d->realPixmap = currentPixmap;
+            setPixmap(d->alternatePixmap);
+        }
+    }
+#else
     if (!d->alternatePixmap.isNull() && pixmap()) {
         d->realPixmap = *pixmap();
         setPixmap(d->alternatePixmap);
     }
+#endif
 
     if (d->glowEnabled || d->floatEnabled) {
         d->timer->stop();
@@ -291,16 +296,22 @@ void KUrlLabel::enterEvent(QEvent *event)
             setUnderline(true);
         }
     }
-
     emit enteredUrl();
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 65)
     emit enteredUrl(d->url);
+#endif
 }
 
 void KUrlLabel::leaveEvent(QEvent *event)
 {
     QLabel::leaveEvent(event);
 
-    if (!d->alternatePixmap.isNull() && pixmap()) {
+    if (!d->alternatePixmap.isNull() &&
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+        !pixmap(Qt::ReturnByValue).isNull()) {
+#else
+        pixmap()) {
+#endif
         setPixmap(d->realPixmap);
     }
 
@@ -309,9 +320,10 @@ void KUrlLabel::leaveEvent(QEvent *event)
     }
 
     setUnderline(d->realUnderlined);
-
     emit leftUrl();
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 65)
     emit leftUrl(d->url);
+#endif
 }
 
 bool KUrlLabel::event(QEvent *event)
@@ -322,8 +334,8 @@ bool KUrlLabel::event(QEvent *event)
          */
         QPalette palette = parentWidget() ? parentWidget()->palette() : qApp->palette();
 
-        palette.setBrush(QPalette::Base, palette.brush(QPalette::Normal, QPalette::Background));
-        palette.setColor(QPalette::Foreground, this->palette().color(QPalette::Active, QPalette::Foreground));
+        palette.setBrush(QPalette::Base, palette.brush(QPalette::Normal, QPalette::Window));
+        palette.setColor(QPalette::WindowText, this->palette().color(QPalette::Active, QPalette::WindowText));
         setPalette(palette);
 
         d->linkColor = palette.color(QPalette::Active, QPalette::Link);
